
From: Zachary Amsden <zach@vmware.com>

Make the generic version of ptep_set_wrprotect a macro.  This is good for code
uniformity, and fixes the build for architectures which include pgtable.h
through headers into assembly code, but do not define a ptep_set_wrprotect
function.

Signed-off-by: Zachary Amsden <zach@vmware.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 include/asm-generic/pgtable.h |   11 ++++++-----
 1 files changed, 6 insertions(+), 5 deletions(-)

diff -puN include/asm-generic/pgtable.h~i386-virtualization-make-generic-set-wrprotect-a-macro include/asm-generic/pgtable.h
--- devel/include/asm-generic/pgtable.h~i386-virtualization-make-generic-set-wrprotect-a-macro	2005-09-07 20:10:35.000000000 -0700
+++ devel-akpm/include/asm-generic/pgtable.h	2005-09-07 20:10:35.000000000 -0700
@@ -128,11 +128,12 @@ do {									\
 #endif
 
 #ifndef __HAVE_ARCH_PTEP_SET_WRPROTECT
-static inline void ptep_set_wrprotect(struct mm_struct *mm, unsigned long address, pte_t *ptep)
-{
-	pte_t old_pte = *ptep;
-	set_pte_at(mm, address, ptep, pte_wrprotect(old_pte));
-}
+#define ptep_set_wrprotect(__mm, __address, __ptep)			\
+({									\
+	pte_t __old_pte = *(__ptep);					\
+	set_pte_at((__mm), (__address), (__ptep),			\
+			pte_wrprotect(__old_pte));			\
+})
 #endif
 
 #ifndef __HAVE_ARCH_PTE_SAME
_
